@@ -1,8 +1,6 @@
 /*
-  $NiH: set_comment_all.c,v 1.2 2006/04/23 13:28:41 wiz Exp $
-
   set_comment_all.c -- set global and file comments
-  Copyright (C) 2006 Dieter Baron and Thomas Klausner
+  Copyright (C) 2006-2013 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
   The authors can be contacted at <libzip@nih.at>
@@ -40,7 +38,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "zip.h"
+#include "zipint.h"
 
 const char *prg;
 const char *new_archive_comment="This is the new,\r\n"
@@ -67,21 +65,21 @@ main(int argc, char *argv[])
     
     if ((za=zip_open(archive, 0, &err)) == NULL) {
 	zip_error_to_str(buf, sizeof(buf), err, errno);
-	fprintf(stderr, "%s: can't open zip archive `%s': %s\n", prg,
+	fprintf(stderr, "%s: can't open zip archive '%s': %s\n", prg,
 		archive, buf);
 	return 1;
     }
 
     if (zip_set_archive_comment(za, new_archive_comment,
-				strlen(new_archive_comment)) < 0) {
+				(zip_uint16_t)strlen(new_archive_comment)) < 0) {
 	zip_error_to_str(buf, sizeof(buf), err, errno);
 	fprintf(stderr, "%s: zip_set_archive_comment failed: %s\n",
 		prg, buf);
     }
 
-    for (i=0; i<zip_get_num_files(za); i++) {
+    for (i=0; i<zip_get_num_entries(za, 0); i++) {
 	snprintf(buf, sizeof(buf), "File comment no %d", i);
-	if (zip_set_file_comment(za, i, buf, strlen(buf)) < 0) {
+	if (zip_file_set_comment(za, i, buf, (zip_uint16_t)strlen(buf), 0) < 0) {
 	    zip_error_to_str(buf, sizeof(buf), err, errno);
 	    fprintf(stderr, "%s: zip_set_file_comment on file %d failed: %s\n",
 		    prg, i, buf);
@@ -89,7 +87,7 @@ main(int argc, char *argv[])
     }
 
     if (zip_close(za) == -1) {
-	fprintf(stderr, "%s: can't close zip archive `%s'\n", prg, archive);
+	fprintf(stderr, "%s: can't close zip archive '%s': %s\n", prg, archive, zip_strerror(za));
 	return 1;
     }
 
